@@ -9,19 +9,21 @@ import pymongo.results
 from mongita import MongitaClientDisk, MongitaClientMemory
 from pymongo import MongoClient
 
+from .cursor import Cursor
+
 
 def client_constructor(engine: str, *args, **kwargs):
 
     if engine == "pymongo":
-        engine_class = MongoClient
+        Engine = MongoClient
     elif engine == "mongita_disk":
-        engine_class = MongitaClientDisk
+        Engine = MongitaClientDisk
     elif engine == "mongita_memory":
-        engine_class = MongitaClientMemory
+        Engine = MongitaClientMemory
     else:
         raise ValueError(f"Invalid engine '{engine}'")
 
-    class MongoClassClient(engine_class):
+    class MongoClassClient(Engine):
 
         """
         Parameters
@@ -51,6 +53,25 @@ def client_constructor(engine: str, *args, **kwargs):
                 return database
             return self[database]
 
+        def get_db(
+            self, database: str
+        ) -> Union[pymongo.database.Database, mongita.database.Database]:
+            """
+            Get a database. Equivalent to `client["database"]`. This method exists simply because type hinting seems to be broken, nothing more.
+
+            Parameters
+            ----------
+            `database` : str
+                The name of the database.
+
+            Returns
+            -------
+            `Union[pymongo.database.Database, mongita.database.Database]` :
+                The `Database` object of the underlying engine.
+            """
+
+            return self[database]
+
         def map_document(
             self, data: dict, collection: str, database: str, force_nested: bool = False
         ) -> object:
@@ -337,10 +358,10 @@ def client_constructor(engine: str, *args, **kwargs):
             *args,
             database: Union[str, pymongo.database.Database] = None,
             **kwargs,
-        ) -> List[object]:
+        ) -> Cursor:
 
             """
-            Find multiple documents and convert each onto a mongoclass that maps to the collection of the document.
+            Find multiple documents and return a `Cursor` that you can iterate over that contains the documents as a mongoclass.
 
             Parameters
             ----------
@@ -355,13 +376,16 @@ def client_constructor(engine: str, *args, **kwargs):
 
             Returns
             -------
-            `List[object]` :
-                A list of mongoclasses containing the document's data.
+            `Cursor`:
+                A cursor similar to pymongo that you can iterate over to get the results.
             """
 
             db = self.__choose_database(database)
             query = db[collection].find(*args, **kwargs)
-            return [self.map_document(x, collection, db.name) for x in query]
+            cursor = Cursor(
+                query, self.map_document, collection, db.name, self._engine_used
+            )
+            return cursor
 
         def insert_classes(
             self, mongoclasses: Union[object, List[object]], *args, **kwargs
